==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/DynamicDeliveryAttributeMappingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.DynamicDeliveryAttributeMappingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Dynamic delivery attribute mapping details.
 * @property name Name of the delivery attribute or header.
 * @property sourceField JSON path in the event which contains attribute value.
 * @property type Type of the delivery attribute or header name.
 * Expected value is 'Dynamic'.
 */
public data class DynamicDeliveryAttributeMappingArgs(
    public val name: Output<String>? = null,
    public val sourceField: Output<String>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.DynamicDeliveryAttributeMappingArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.DynamicDeliveryAttributeMappingArgs =
        com.pulumi.azurenative.eventgrid.inputs.DynamicDeliveryAttributeMappingArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .sourceField(sourceField?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DynamicDeliveryAttributeMappingArgs].
 */
@PulumiTagMarker
public class DynamicDeliveryAttributeMappingArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var sourceField: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value Name of the delivery attribute or header.
     */
    @JvmName("ueawnnlxinlapkig")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value JSON path in the event which contains attribute value.
     */
    @JvmName("yngtaklimbcihvvw")
    public suspend fun sourceField(`value`: Output<String>) {
        this.sourceField = value
    }

    /**
     * @param value Type of the delivery attribute or header name.
     * Expected value is 'Dynamic'.
     */
    @JvmName("omufkbcedcmntkcy")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Name of the delivery attribute or header.
     */
    @JvmName("rrtjoldtqlqxlhaf")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value JSON path in the event which contains attribute value.
     */
    @JvmName("dyvacxeaoobjtlcd")
    public suspend fun sourceField(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceField = mapped
    }

    /**
     * @param value Type of the delivery attribute or header name.
     * Expected value is 'Dynamic'.
     */
    @JvmName("wlmfhhgvpvttuqmw")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): DynamicDeliveryAttributeMappingArgs = DynamicDeliveryAttributeMappingArgs(
        name = name,
        sourceField = sourceField,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/DynamicDeliveryAttributeMappingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.DynamicDeliveryAttributeMappingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Dynamic delivery attribute mapping details.
 * @property name Name of the delivery attribute or header.
 * @property sourceField JSON path in the event which contains attribute value.
 * @property type Type of the delivery attribute or header name.
 * Expected value is 'Dynamic'.
 */
public data class DynamicDeliveryAttributeMappingArgs(
    public val name: Output<String>? = null,
    public val sourceField: Output<String>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.DynamicDeliveryAttributeMappingArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.DynamicDeliveryAttributeMappingArgs =
        com.pulumi.azurenative.eventgrid.inputs.DynamicDeliveryAttributeMappingArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .sourceField(sourceField?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DynamicDeliveryAttributeMappingArgs].
 */
@PulumiTagMarker
public class DynamicDeliveryAttributeMappingArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var sourceField: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value Name of the delivery attribute or header.
     */
    @JvmName("ugenlcdnaestdndu")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value JSON path in the event which contains attribute value.
     */
    @JvmName("yrwvbhfrrxgquuyh")
    public suspend fun sourceField(`value`: Output<String>) {
        this.sourceField = value
    }

    /**
     * @param value Type of the delivery attribute or header name.
     * Expected value is 'Dynamic'.
     */
    @JvmName("guydqmddsgqapaam")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Name of the delivery attribute or header.
     */
    @JvmName("xpggvphyxpgorssa")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value JSON path in the event which contains attribute value.
     */
    @JvmName("bvutwjdtabignxgr")
    public suspend fun sourceField(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceField = mapped
    }

    /**
     * @param value Type of the delivery attribute or header name.
     * Expected value is 'Dynamic'.
     */
    @JvmName("jukgnrnbwmndlham")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): DynamicDeliveryAttributeMappingArgs = DynamicDeliveryAttributeMappingArgs(
        name = name,
        sourceField = sourceField,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
